URL Example
===========

Example for Api's url request is ``http://127.0.0.1:8000/api/v1/messages.json``, where:

* ``http://127.0.0.1:8000``  - host name
* ``/api`` - endpoint
* ``v1`` - api version number
* ``messages`` - resources
* ``.json`` - response format
